<?php


/**
 * @file
 * Provides API documentation for the gigya module.
 */

/*
 * All Gigya parameters go through druapl_alter function so a other modules could modify or add parameters
 * blow is a list of the functions and a sort explanation
 */

/*
 * Implementation of hook_gigya_global_conf_alter()
 *
 * This hook is called before adding the gigya global configuration parameters to javascript settings
 * the default parameters the list of providers enabled or disabled  and the language
 * a list of available parameters can be fount at the Gigya  developers site http://developers.gigya.com/020_Client_API/010_Objects/Conf_object
 * note that these parameters are not added as drupal js setting but as and object to in gigya include script in the page head
 */
function hook_gigya_global_conf_alter($gigya_js_settings) {
  global $language;
  if ($language->language == 'fr') {
    //if the site language is French change gigya language to French
    $gigya_js_settings['lang'] = 'fr';
  }
}


/*
 * Implementation of hook_gigya_notify_login_user_info_alter()
 *
 * This hook is called before calling gigya_notify_login function the object to change here is the user info that gets sent to gigya
 * valide fields are nickname, photoURL, thumbnailURL, firstName, lastName, gender, age, email
 * The relevant  Gigya  developers site page is http://developers.gigya.com/020_Client_API/020_Methods/socialize.notifyLogin
 */

function hook_notify_login_user_info_alter($gigya_user_info) {
  $gigya_user_info['email'] = 'email@this_site.com';
}


/*
 * Implementation of hook_gigya_loginui_alter()
 *
 * This hook is called before adding the gigya.socialize.showLoginUI configuration parameters to javascript settings
 * a list of available parameters can be fount at the Gigya  developers site http://developers.gigya.com/020_Client_API/020_Methods/Socialize.showLoginUI
 *
 */

function hook_gigya_loginui_alter($gigya_login_params) {
  $gigya_login_params['showWhatsThis'] = TRUE;
  $gigya_login_params['whatsThisText'] = t('Some explanation text about the login widget');
}


/*
 * Implementation of hook_gigya_connectui_alter()
 *
 * This hook is called before adding the gigya.socialize.showAddConnectionsUI configuration parameters to javascript settings
 * a list of available parameters can be fount at the Gigya  developers site http://developers.gigya.com/020_Client_API/020_Methods/socialize.showAddConnectionsUI
 *
 */

function hook_gigya_loginui_alter($gigya_connect_params) {
  $gigya_connect_params['showWhatsThis'] = TRUE;
  $gigya_connect_params['whatsThisText'] = t('Some explanation text about the login widget');
}


/*
 * Implementation of hook_gigya_sharebar_alter()
 *
 * This hook is called before adding the socialize.showShareBarUI configuration parameters to javascript settings
 * An explanation of the plugin is available here http://developers.gigya.com/010_Developer_Guide/18_Plugins/015_Share_Bar
 * a list of available parameters can be fount at the Gigya  developers site http://developers.gigya.com/020_Client_API/020_Methods/socialize.showAddConnectionsUI
 *
 */

function hook_gigya_sharebar_alter($share_settings) {
  $share_settings['grayedOutScreenOpacity'] = 30;
}

/*
 * Implementation of hook_gigya_reactions_alter()
 *
 * This hook is called before adding the socialize.showReactionsBarUI configuration parameters to javascript settings
 * An explanation of the plugin is available here http://developers.gigya.com/010_Developer_Guide/18_Plugins/030_The_Reactions_Plugin
 * a list of available parameters can be fount at the Gigya  developers site http://developers.gigya.com/020_Client_API/020_Methods/socialize.showReactionsBarUI
 *
 */

function hook_gigya_reactions_alter($reactions_settings) {
  $reactions_settings['promptShare'] = FALSE;
}


/*
 * Implementation of hook_gigya_shareui_alter()
 *
 * This hook is called before adding the socialize.showShareUI configuration parameters to javascript settings
 * a list of available parameters can be fount at the Gigya  developers site http://developers.gigya.com/020_Client_API/020_Methods/socialize.showShareUI
 * note this is a called as a rules action
 *
 */

function hook_gigya_shareui_alter($shareui_parms) {
  $shareui_parms['showSuccessMessage'] = FALSE;
}


/*
 * Implementation of hook_gigya_comments_alter()
 *
 * This hook is called before adding the socialize.showCommentsUI configuration parameters to javascript settings
 * An explanation of the plugin is available here http://developers.gigya.com/010_Developer_Guide/18_Plugins/020_The_Comments_Plugin
 * a list of available parameters can be fount at the Gigya  developers site http://developers.gigya.com/020_Client_API/020_Methods/socialize.showCommentsUI
 *
 */

function hook_gigya_comments_alter($comments_parmes) {
  $comments_parmes['useSiteLogin'] = TRUE;
  $comments_parmes['onSiteLoginClicked'] = 'onSiteLoginHandler' // registering to the onSiteLoginClicked event
}


/*
 * Implementation of hook_gigya_create_user_alter()
 *
 * This hook is called before adding creating a drupal user from social login.
 *
 */

function hook_gigya_create_user_alter($form_state, $bio) {
  //use the nickname provided from gigya as a username
  $form_state['values']['name'] = $bio['nickname'];
}
